And here's the Signal code:

//+------------------------------------------------------------------+
//|                                                     SignalMA.mqh |
//|                   Copyright 2009-2013, MetaQuotes Software Corp. |
//|                                              http://www.mql5.com |
//+------------------------------------------------------------------+
#include <Expert\ExpertSignal.mqh>
// wizard description start
//+-------------------------------------------------------------------------+
//| Description of the class                                                |
//| Title=Sinal BoWilliams                                                  |
//| Type=SignalAdvanced                                                     |
//| Name=Sinal Estratégia Lucas Seno                                        |
//| ShortName=BOS                                                           |
//| Class=CSignalSeno2                                                      |
//| Page=signal_ma                                                          |
//| Parameter=HorarioInicio, int, 915, Horario de início das operacoes      |
//| Parameter=HorarioFim, int, 1730, Horario de fim das operacoes           |
//| Parameter=PeriodFMA,int,34,Periodo EMA1                                 |
//| Parameter=HipFMA,float,2000.0,Hipotenusa para cálculo do seno           |
//| Parameter=TempoEspera,int,12,Tempo para aguardar durante o cruzamento   |
//| Parameter=ValorCompra,double,0.2, Valor do seno para compra             |
//| Parameter=ValorVenda,double,-0.2, Valor do seno para venda               |
//+-------------------------------------------------------------------------+
// wizard description end
//+------------------------------------------------------------------+
//| Class CSignalSeno2.                                                |
//| Purpose: Class of generator of trade signals based on            |
//|          the 'Seno'.                                               |
//| Is derived from the CExpertSignal class.                         |
//+------------------------------------------------------------------+
class CSignalSeno2 : public CExpertSignal
  {
protected:
   CiMA              m_ma1;            // Indicador EMA1
   CiMA              m_ma2;
   CiMA              m_maBoShort;
   CiMA              m_maBoMedium;
   CiMA              m_maBoLong;
   CiRSI             m_rsi;
   CiStochastic      m_stoc;   
   CPositionInfo     m_position;
   ulong             expertMagicNumber;
   bool              permitirNovasOperacoes;   
   datetime          horarioCruzamento;
   datetime          horarioCruzamento2;
   //--- adjusted parameters
   int               m_horario_inicio;
   int               m_horario_fim;
   int               m_ma1_period;      // the "period of averaging" parameter of the indicator      
   int               m_ma2_period;
   bool              m_use_bo_avgs;
   int               m_maBoShort_period;
   int               m_maBoMedium_period;
   int               m_maBoLong_period;
   float             m_hip_fma;
   int               m_tempo_espera;
   int               m_tempo_espera2;
   double            m_valor_compra;
   double            m_valor_venda;
   int               m_rsi_period;
   double            m_rsi_buy;
   double            m_rsi_sell;
   int               m_stoc_period;
   double            m_stoc_buy;
   double            m_stoc_sell;
   //--- "weights" of market models (0-100)
   int               m_pattern_0;      // model 0 "price is on the necessary side from the indicator"
   //  int               m_pattern_1;      // model 1 "price crossed the indicator with opposite direction"
   // int               m_pattern_2;      // model 2 "price crossed the indicator with the same direction"
   // int               m_pattern_3;      // model 3 "piercing"

public:
                     CSignalSeno2(void);
                    ~CSignalSeno2(void);
   //--- methods of setting adjustable parameters
   void              HorarioInicio(int value)             { m_horario_inicio=value;    }
   void              HorarioFim(int value)                { m_horario_fim=value;       }      
   void              PeriodFMA(int value)                 { m_ma1_period=value;        } 
   void              PeriodSMA(int value)                 { m_ma2_period=value;        }
   void              UseBoAvgs(bool value)                { m_use_bo_avgs=value;       }
   void              PeriodBoShort(int value)             { m_maBoShort_period=value;  }
   void              PeriodBoMedium(int value)            { m_maBoMedium_period=value; }
   void              PeriodBoLong(int value)              { m_maBoLong_period=value;   }
   void              TempoEspera(int value)               { m_tempo_espera = value;    }
   void              TempoEspera2(int value)              { m_tempo_espera2=value;     }
   void              ValorCompra(double value)            { m_valor_compra = value;    }
   void              ValorVenda(double value)             { m_valor_venda = value;     }
   void              HipFMA(float value)                  { m_hip_fma = value;         }
   void              RSIPeriodo(int value)                { m_rsi_period = value;      }
   void              RSICompra(double value)              { m_rsi_buy = value;         }
   void              RSIVenda(double value)               { m_rsi_sell = value;        }
   void              EstocPeriodo(int value)              { m_stoc_period = value;     }
   void              EstocCompra(double value)            { m_stoc_buy = value;        }
   void              EstocVenda(double value)             { m_stoc_sell = value;       }

   void              setExpertNumber(ulong value)         { expertMagicNumber = value; }   
      
   //--- method of verification of settings
   virtual bool      ValidationSettings(void);
   //--- method of creating the indicator and timeseries
   virtual bool      InitIndicators(CIndicators *indicators);
   //--- methods of checking if the market models are formed
   virtual int       LongCondition(void);
   virtual int       ShortCondition(void);

   virtual bool      SelectPosition(void);
   virtual void      TestarPermissaoDeOperacoes(void);

   virtual double    IFMASen(int idx);
   virtual double    IFMASen2(int idx);   
   virtual void      TestarCruzamento(int idx);    
   virtual void      EncontrarCruzamento(void);        
   virtual void      EncontrarCruzamento2(void);

private:
   void              SetPermissao(bool value)             { permitirNovasOperacoes = value;}   

protected:
   //--- method of initialization of the indicator
   bool              InitCustomIndicators(CIndicators *indicators);
   //--- methods of getting data
   double            FMA(int ind)      { return(m_ma1.Main(ind));                            }   
   double            IFMA(int ind)     { return(m_ma1.Main(ind) - m_ma1.Main(ind+1));        }
   double            SMA(int ind)      { return(m_ma2.Main(ind));                            }
   double            ISMA(int ind)     { return(m_ma2.Main(ind) - m_ma2.Main(ind+1));        }
   double            MABShort(int ind) { return(m_maBoShort.Main(ind));                      }
   double            IMABShort(int ind){ return(m_maBoShort.Main(ind) - m_maBoShort.Main(ind+1));}
   double            MABMedium(int ind){ return(m_maBoMedium.Main(ind));                     }
   double           IMABMedium(int ind){ return(m_maBoMedium.Main(ind) - m_maBoMedium.Main(ind+1));}
   double            MABLong(int ind)  { return(m_maBoLong.Main(ind));                       }
   double            IMABLong(int ind) { return(m_maBoLong.Main(ind) - m_maBoLong.Main(ind+1));} 
   double            RSI(int ind)      { return(m_rsi.Main(ind));                            }
   double            STOC(int ind)     { return(m_stoc.Main(ind));                           }   
   double            Close(int ind)    { return(m_close.GetData(ind));                       }
   datetime          Time(int ind)     { return(m_time.GetData(ind));                        }
   void              FindCross(void)   { EncontrarCruzamento();                              }
  };
//+------------------------------------------------------------------+
//| Constructor                                                      |
//+------------------------------------------------------------------+
CSignalSeno2::CSignalSeno2(void) : m_horario_inicio(915),
   m_horario_fim(1730),
   m_ma1_period(34),
   m_ma2_period(50),
   m_use_bo_avgs(true),
   m_maBoShort_period(10),
   m_maBoMedium_period(20),
   m_maBoLong_period(30),     
   m_hip_fma(2000.0),
   m_tempo_espera(12),
   m_tempo_espera2(20),
   m_valor_compra(0.2),
   m_valor_venda(-0.2),
   permitirNovasOperacoes(true),   
   horarioCruzamento(NULL)
  {
//--- initialization of protected data
   m_used_series=USE_SERIES_CLOSE + USE_SERIES_TIME + USE_SERIES_HIGH + USE_SERIES_LOW;
  }
//+------------------------------------------------------------------+
//| Destructor                                                       |
//+------------------------------------------------------------------+
CSignalSeno2::~CSignalSeno2(void)
  {
  }
//+------------------------------------------------------------------+
//| Validation settings protected data.                              |
//+------------------------------------------------------------------+
bool CSignalSeno2::ValidationSettings(void)
  {
//--- validation settings of additional filters
   if(!CExpertSignal::ValidationSettings())
      return(false);
//--- initial data checks
   if(m_ma1_period<=0)
     {
      printf(__FUNCTION__+": Período da MA1 tem que ser maior que 0");
      return(false);
     }   

//--- ok
   return(true);
  }
//+------------------------------------------------------------------+
//| Create indicators.                                               |
//+------------------------------------------------------------------+
bool CSignalSeno2::InitIndicators(CIndicators *indicators)
  {   
//--- check pointer
   if(indicators==NULL)
      return(false);
//--- initialization of indicators and timeseries of additional filters
   if(!CExpertSignal::InitIndicators(indicators))
      return(false);
//--- create and initialize MA indicator
   if(!InitCustomIndicators(indicators))
      return(false);
//--- ok   
   return(true);     
  }
//+------------------------------------------------------------------+
//| Initialize MA indicators.                                        |
//+------------------------------------------------------------------+
bool CSignalSeno2::InitCustomIndicators(CIndicators *indicators)
  {
//--- check pointer
   if(indicators==NULL)
      return(false);
//--- adiciona EMA1
   TesterHideIndicators(true);
   if(!indicators.Add(GetPointer(m_ma1)))
     {
      printf(__FUNCTION__+": error adding mma1");
      return(false);
     }
//--- initialize EMA1
   if(!m_ma1.Create(m_symbol.Name(),m_period,m_ma1_period,0,MODE_EMA,PRICE_CLOSE))
     {
      printf(__FUNCTION__+": error initializing mma1");
      return(false);
     }
//--- adiciona EMA2
   if(!indicators.Add(GetPointer(m_ma2)))
     {
      printf(__FUNCTION__+": error adding mma2");
      return(false);
     }
//--- initialize EMA2
   if(!m_ma2.Create(m_symbol.Name(),m_period,m_ma2_period,0,MODE_EMA,PRICE_CLOSE))
     {
      printf(__FUNCTION__+": error initializing mma2");
      return(false);
     }     
//--- adiciona MABoShort
   if(!indicators.Add(GetPointer(m_maBoShort)))
     {
      printf(__FUNCTION__+": error adding mmaBoShort");
      return(false);
     }
//--- initialize MABoShort
   if(!m_maBoShort.Create(m_symbol.Name(),m_period,m_maBoShort_period,0,MODE_SMA,PRICE_CLOSE))
     {
      printf(__FUNCTION__+": error initializing mmaBoShort");
      return(false);
     }
//--- adiciona MABoMedium
   if(!indicators.Add(GetPointer(m_maBoMedium)))
     {
      printf(__FUNCTION__+": error adding mmaBoMedium");
      return(false);
     }
//--- initialize MABoMedium
   if(!m_maBoMedium.Create(m_symbol.Name(),m_period,m_maBoMedium_period,0,MODE_SMA,PRICE_CLOSE))
     {
      printf(__FUNCTION__+": error initializing mmaBoMedium");
      return(false);
     }  
//--- adiciona MABoLong
   if(!indicators.Add(GetPointer(m_maBoLong)))
     {
      printf(__FUNCTION__+": error adding mmaBoLong");
      return(false);
     }
//--- initialize MABoLong
   if(!m_maBoLong.Create(m_symbol.Name(),m_period,m_maBoLong_period,0,MODE_SMA,PRICE_CLOSE))
     {
      printf(__FUNCTION__+": error initializing mmaBoLong");
      return(false);
     }          
//-- adiciona Close
   if(!indicators.Add(GetPointer(m_close)))
     {
      printf(__FUNCTION__+": error adding close");
      return(false);
     }
//-- Inicializa close;
   if(!m_close.Create(m_symbol.Name(), m_period))
     {
      printf(__FUNCTION__+": Error initializing close");
      return(false);
     }
   if(!indicators.Add(GetPointer(m_time)))
     {
      printf(__FUNCTION__+": error adding mTime");
      return(false);
     }
   if(!m_time.Create(m_symbol.Name(), m_period))
     {
      printf(__FUNCTION__+": Error initializing time");
      return(false);
     }   
//--- adiciona RSI
   if(!indicators.Add(GetPointer(m_rsi)))
     {
      printf(__FUNCTION__+": error adding rsi");
      return(false);
     }
//--- initialize RSI
   if(!m_rsi.Create(m_symbol.Name(), m_period, m_rsi_period, PRICE_CLOSE))
     {
      printf(__FUNCTION__+": error initializing rsi");
      return(false);
     }
//--- adiciona STOC
   if(!indicators.Add(GetPointer(m_stoc)))
     {
      printf(__FUNCTION__+": error adding stoc");
      return(false);
     }
//--- initialize STOC
   if(!m_stoc.Create(m_symbol.Name(), m_period, m_stoc_period, m_stoc_period, 3, MODE_SMA, STO_LOWHIGH))
     {
      printf(__FUNCTION__+": error initializing stochastic");
      return(false);
     }          
//--- ok
   return(true);
  }
//+------------------------------------------------------------------+
//| "Voting" that price will grow.                                   |
//+------------------------------------------------------------------+
int CSignalSeno2::LongCondition(void)
  {
   int result=0;
   int idx   =StartIndex();
//--- analyze positional relationship of the close price and the indicator at the first analyzed bar

   MqlDateTime _t;
   TimeToStruct(TimeCurrent(), _t);
   int horaDoDia = _t.hour * 100 + _t.min;
   
   if (horaDoDia == 1204)
      printf("Hey");
   
   bool pos = SelectPosition();
   if(pos && m_position.PositionType() == POSITION_TYPE_BUY && horaDoDia >= m_horario_fim - 1)
      return(-2);

   TestarPermissaoDeOperacoes();
   TestarCruzamento(idx);
   
   datetime diffTimeEntrada;
   if(horarioCruzamento == NULL) {
      diffTimeEntrada = NULL;
   } else diffTimeEntrada = TimeCurrent() - horarioCruzamento;
   
   datetime diffTimeEntrada2;
   if(horarioCruzamento2 == NULL) {
      diffTimeEntrada2 = NULL;
   } else diffTimeEntrada2 = TimeCurrent() - horarioCruzamento2;
   
   double priceValue = Close(idx);
   double ifmaValue = IFMASen(idx);
   double ismaValue = IFMASen2(idx);
   double mablValue = MABLong(idx);
   double mabmValue = MABMedium(idx);
   double mabsValue = MABShort(idx);
   double rsiValue = RSI(idx);
   double stocValue = STOC(idx);
   
   bool boCondition = (m_use_bo_avgs) ? priceValue > mabsValue > mabmValue > mablValue : true;

   if(ifmaValue >= m_valor_compra &&      
      ismaValue >= m_valor_compra &&
      boCondition &&
      rsiValue <= m_rsi_buy &&
      stocValue <= m_stoc_buy &&
      diffTimeEntrada >= m_tempo_espera * 60 &&      
      diffTimeEntrada != NULL &&
      diffTimeEntrada2 >= m_tempo_espera2 * 60 &&
      diffTimeEntrada2 != NULL &&
      permitirNovasOperacoes  &&
      horaDoDia > m_horario_inicio && horaDoDia < m_horario_fim - 2
     )
     {
      if(m_position.PositionType() == POSITION_TYPE_SELL) {
         result = 20;         
      } else result = 10;
      permitirNovasOperacoes = false;
      horarioCruzamento = NULL;
      horarioCruzamento2 = NULL;
      Alert("Trade de compra iniciado");      
     }
     
   // Saída de compra por critério da estratégia
   if(pos && m_position.PositionType() == POSITION_TYPE_BUY &&
     (( diffTimeEntrada >= m_tempo_espera * 60 && diffTimeEntrada != NULL) ||
     ( diffTimeEntrada2 >= m_tempo_espera2 * 60 && diffTimeEntrada2 != NULL))
   ) {
      result = -2;
      Alert("Trade finalizado");
     }

//--- return the result
   return(result);
  }
//+------------------------------------------------------------------+
//| "Voting" that price will fall.                                   |
//+------------------------------------------------------------------+
int CSignalSeno2::ShortCondition(void)
  {
   int result=0;
   int idx   =StartIndex();

   MqlDateTime _t;
   TimeToStruct(TimeCurrent(), _t);
   int horaDoDia = _t.hour * 100 + _t.min;
   
   if (horaDoDia == 1448)
      printf("Hey");
   
   bool pos = SelectPosition();
   if(pos && m_position.PositionType() == POSITION_TYPE_SELL && horaDoDia >= m_horario_fim - 1)
      return(-2);

   TestarPermissaoDeOperacoes();
   TestarCruzamento(idx);
   
   datetime diffTimeEntrada;
   if(horarioCruzamento == NULL) {
      diffTimeEntrada = NULL;
   } else diffTimeEntrada = TimeCurrent() - horarioCruzamento;       
   
   datetime diffTimeEntrada2;
   if(horarioCruzamento2 == NULL) {
      diffTimeEntrada2 = NULL;
   } else diffTimeEntrada2 = TimeCurrent() - horarioCruzamento2;
   
   double priceValue = Close(idx);
   double ifmaValue = IFMASen(idx);
   double ismaValue = IFMASen2(idx);
   double mablValue = MABLong(idx);
   double mabmValue = MABMedium(idx);
   double mabsValue = MABShort(idx);
   double rsiValue = RSI(idx);
   double stocValue = STOC(idx);
   
   bool boCondition = (m_use_bo_avgs) ? priceValue < mabsValue < mabmValue < mablValue : true;

   if(ifmaValue <= m_valor_venda &&
      ismaValue <= m_valor_venda &&
      boCondition &&      
      rsiValue >= m_rsi_sell &&
      stocValue >= m_stoc_sell &&
      diffTimeEntrada >= m_tempo_espera * 60 &&
      diffTimeEntrada != NULL &&
      diffTimeEntrada2 >= m_tempo_espera2 * 60 &&
      diffTimeEntrada2 != NULL &&
      permitirNovasOperacoes  &&
      horaDoDia > m_horario_inicio && horaDoDia < m_horario_fim - 2
     )
     {
      if(m_position.PositionType() == POSITION_TYPE_BUY) {
         result = 20;         
      } else result = 10;
      permitirNovasOperacoes = false;
      Alert("Trade de venda iniciado");
      horarioCruzamento = NULL;      
      horarioCruzamento2 = NULL;
     }
     
   if(pos && m_position.PositionType() == POSITION_TYPE_SELL &&
      ((diffTimeEntrada >= m_tempo_espera * 60 && diffTimeEntrada != NULL) ||
       (diffTimeEntrada2 >= m_tempo_espera2 * 60 && diffTimeEntrada2 != NULL))
   ) {
      result = -2;
      Alert("Trade finalizado");
     }
          
//--- return the result
   return(result);
  }
//+------------------------------------------------------------------+

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
double CSignalSeno2::IFMASen(int idx)
  {
   double ifma = IFMA(idx);   
   double hip = MathSqrt(ifma * ifma + m_hip_fma);
   double sen = ifma / hip;

   return sen;
  }
  
double CSignalSeno2::IFMASen2(int idx)
  {
   double ifma = ISMA(idx);
   double hip = MathSqrt(ifma * ifma + m_hip_fma);
   double sen = ifma / hip;
   
   return sen;
  }
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
bool CSignalSeno2::SelectPosition()
  {
   bool res = false;
   if(IsHedging())
     {
      res = m_position.SelectByMagic(m_symbol.Name(), expertMagicNumber);
     }
   else
     {
      res = m_position.Select(m_symbol.Name());
     }

   return res;
  }

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
void CSignalSeno2::TestarPermissaoDeOperacoes()
  {
   int idx = StartIndex();

   if(!SelectPosition())
     {
      SetPermissao(true);
     }
  }
//+------------------------------------------------------------------+

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
void CSignalSeno2::TestarCruzamento(int idx)
  {
   float valorCruzamento = 0.0;
   bool pos = SelectPosition();

   MqlDateTime _t;
   TimeToStruct(TimeCurrent(), _t);
   int h = _t.hour * 100 + _t.min;
   datetime horaDoDia = TimeCurrent();

   if((h < m_horario_inicio) || (h > m_horario_fim))
     {
      horarioCruzamento = NULL;
      horarioCruzamento2 = NULL;
     }
     
   // horarioCruzamentoEntrada
   
   double ifSen = IFMASen(idx);
   double ifSenAnt = IFMASen(idx+1);

   if((!pos) &&
      IFMASen(idx) > valorCruzamento &&
      IFMASen(idx+1) < valorCruzamento
   ) horarioCruzamento = horaDoDia;
   else if((!pos) &&
      IFMASen(idx) < valorCruzamento &&
      IFMASen(idx+1) > valorCruzamento
   ) horarioCruzamento = horaDoDia;
   else if(pos && m_position.PositionType() == POSITION_TYPE_BUY &&
      IFMASen(idx) < valorCruzamento &&
      IFMASen(idx+1) > valorCruzamento
   ) horarioCruzamento = horaDoDia;           
   else if(pos && m_position.PositionType() == POSITION_TYPE_BUY &&
      IFMASen(idx) > valorCruzamento &&
      IFMASen(idx+1) < valorCruzamento
   ) horarioCruzamento = NULL;              
   else if(pos && m_position.PositionType() == POSITION_TYPE_SELL &&
      IFMASen(idx) < valorCruzamento &&
      IFMASen(idx+1) > valorCruzamento
   ) horarioCruzamento = NULL;
   else if(pos && m_position.PositionType() == POSITION_TYPE_SELL &&
      IFMASen(idx) > valorCruzamento &&
      IFMASen(idx+1) < valorCruzamento
   ) horarioCruzamento = horaDoDia;
   
   // Cruzamento2
   
   if((!pos) &&
      IFMASen2(idx) > valorCruzamento &&
      IFMASen2(idx+1) < valorCruzamento
   ) horarioCruzamento2 = horaDoDia;
   else if((!pos) &&
      IFMASen2(idx) < valorCruzamento &&
      IFMASen2(idx+1) > valorCruzamento
   ) horarioCruzamento2 = horaDoDia;
   else if(pos && m_position.PositionType() == POSITION_TYPE_BUY &&
      IFMASen2(idx) < valorCruzamento &&
      IFMASen2(idx+1) > valorCruzamento
   ) horarioCruzamento2 = horaDoDia;           
   else if(pos && m_position.PositionType() == POSITION_TYPE_BUY &&
      IFMASen2(idx) > valorCruzamento &&
      IFMASen2(idx+1) < valorCruzamento
   ) horarioCruzamento2 = NULL;              
   else if(pos && m_position.PositionType() == POSITION_TYPE_SELL &&
      IFMASen2(idx) < valorCruzamento &&
      IFMASen2(idx+1) > valorCruzamento
   ) horarioCruzamento2 = NULL;
   else if(pos && m_position.PositionType() == POSITION_TYPE_SELL &&
      IFMASen2(idx) > valorCruzamento &&
      IFMASen2(idx+1) < valorCruzamento
   ) horarioCruzamento2 = horaDoDia;    
   
   if(horarioCruzamento != NULL) {
      MqlDateTime strF;
      MqlDateTime strF2;
      MqlDateTime strPredict;      
      TimeToStruct(horarioCruzamento, strF);
      TimeToStruct(horarioCruzamento2, strF2);            
      
      if(horarioCruzamento + m_tempo_espera * 60 > horarioCruzamento2 + m_tempo_espera2 * 60) {
         TimeToStruct(horarioCruzamento + m_tempo_espera * 60, strPredict);
      } else TimeToStruct(horarioCruzamento2 + m_tempo_espera2 * 60, strPredict);
      
      Comment(StringFormat("horarioCruzamento: %02d:%02d | horarioCruzamento2: %02d:%02d | horarioEntrada: %02d:%02d", strF.hour, strF.min, strF2.hour, strF2.min, strPredict.hour, strPredict.min));
   }
  }
  
void CSignalSeno2::EncontrarCruzamento()
  {
   int idx = StartIndex();   
   datetime barTime = Time(idx);
   MqlDateTime _t;
   TimeCurrent(_t);
   
   double currentValue = IFMASen(idx);   
   if(currentValue >= 0) {
      while(currentValue >= 0 && (_t.hour * 100 + _t.min) > m_horario_inicio) {         
         idx++;
         
         currentValue = IFMASen(idx);         
         if(currentValue < 0) {            
            //return barTime;
            horarioCruzamento = barTime;
            Comment(StringFormat("horarioCruzamento: %02d:%02d", _t.hour, _t.min));
            return;
         }                  
         barTime = Time(idx);
         TimeToStruct(barTime, _t);
      }
   } else {
      while(currentValue < 0 && (_t.hour * 100 + _t.min) > m_horario_inicio) {
         idx++;
         
         currentValue = IFMASen(idx);         
         if(currentValue > 0) {
            //return barTime;
            horarioCruzamento = barTime;
            Comment(StringFormat("horarioCruzamento: %02d:%02d", _t.hour, _t.min));
            return;            
         }                 
         barTime = Time(idx);
         TimeToStruct(barTime, _t);
      }
   }
   Comment("Cruzamento não encontrado");
   horarioCruzamento = NULL;
   
   EncontrarCruzamento2();   
  }
  
void CSignalSeno2::EncontrarCruzamento2()
  {
   int idx = StartIndex();   
   datetime barTime = Time(idx);
   MqlDateTime _t;
   TimeCurrent(_t);
   
   double currentValue = IFMASen2(idx);   
   if(currentValue >= 0) {
      while(currentValue >= 0 && (_t.hour * 100 + _t.min) > m_horario_inicio) {         
         idx++;
         
         currentValue = IFMASen2(idx);         
         if(currentValue < 0) {            
            //return barTime;
            horarioCruzamento2 = barTime;
            Comment(StringFormat("horarioCruzamento2: %02d:%02d", _t.hour, _t.min));
            return;
         }                  
         barTime = Time(idx);
         TimeToStruct(barTime, _t);
      }
   } else {
      while(currentValue < 0 && (_t.hour * 100 + _t.min) > m_horario_inicio) {
         idx++;
         
         currentValue = IFMASen2(idx);         
         if(currentValue > 0) {
            //return barTime;
            horarioCruzamento2 = barTime;
            Comment(StringFormat("horarioCruzamento2: %02d:%02d", _t.hour, _t.min));
            return;            
         }                 
         barTime = Time(idx);
         TimeToStruct(barTime, _t);
      }
   }
   Comment("Cruzamento não encontrado");
   horarioCruzamento2 = NULL;   
  }  
//+------------------------------------------------------------------+